pub enum LengthError {
DataTooBig,
ZeroLength,
Truncated,
}Expand description
An error that resulted from improper item encoding.
Variants
DataTooBig
The data length was too big for this item.
ZeroLength
A data length of zero is not allowed in this item.
Truncated
Ran out of bytes trying to decode this item.