pub fn decode_one<Iter>(
iter: Iter,
context: &mut DecoderContext,
) -> Option<Result<DecodedItem, LengthError>>Expand description
Decode one item from its encoded bytes.
This will consume one or more bytes from the input iterator.
pub fn decode_one<Iter>(
iter: Iter,
context: &mut DecoderContext,
) -> Option<Result<DecodedItem, LengthError>>Decode one item from its encoded bytes.
This will consume one or more bytes from the input iterator.