pub struct TextDecoder<W> { /* private fields */ }Expand description
Decode an HID report descriptor to plain text.
Implementations
Sourceimpl<W> TextDecoder<W>where
W: Write,
impl<W> TextDecoder<W>where
W: Write,
Sourcepub fn new(writer: W) -> Self
pub fn new(writer: W) -> Self
Create a new TextDecoder, by specifying where the output will be written.
Example
let mut decoder = TextDecoder::new(std::io::stdout());Sourcepub fn display_tag_type(self) -> Self
pub fn display_tag_type(self) -> Self
Display the item tag types, i.e. Main, Global, Local.
Sourcepub fn display_raw_bytes(self) -> Self
pub fn display_raw_bytes(self) -> Self
Display the raw bytes that make up each item.